//IBM Java GSS 1.0 sample JAAS-enabled server program

package com.ibm.security.jgss.test;

import com.ibm.security.jgss.Debug;
import com.ibm.security.auth.callback.Krb5CallbackHandler;
import javax.security.auth.Subject;
import javax.security.auth.login.LoginContext;
import java.security.PrivilegedExceptionAction;
 
/**
 * Code example disclaimer
 * IBM grants you a nonexclusive copyright license to use all programming code
 * examples from which you can generate similar function tailored to your own
 * specific needs.
 * All sample code is provided by IBM for illustrative purposes only.
 * These examples have not been thoroughly tested under all conditions.
 * IBM, therefore, cannot guarantee or imply reliability, serviceability, or
 * function of these programs.
 * All programs contained herein are provided to you "AS IS" without any
 * warranties of any kind.
 * The implied warranties of non-infringement, merchantability and fitness
 * for a particular purpose are expressly disclaimed.
 *
 * A Java GSS sample server that uses JAAS.
 * 
 * It does a JAAS login and operates within the JAAS login context so created.
 * 
 * It does not set the JAVA variable 
 * javax.security.auth.useSubjectCredsOnly, leaving
 * the variable to default to true
 * so that Java GSS acquires credentials from the JAAS Subject
 * associated with login context (created by the server).
 * 
 * The JAASServer is equivalent to its superclass {@link Server Server}
 * in all other respects, and it
 * can be run against the non-JAAS sample clients and servers.
 */
 
class JAASServer extends Server
{
    JAASServer(String programName) throws Exception
    {
        super(programName);
    }
 
    static class JAASServerAction implements PrivilegedExceptionAction
    {
        private JAASServer server = null;
 
        JAASServerAction(JAASServer server)
        {
            this.server = server;
        }
 
        public Object run() throws Exception
        {
            server.initialize();
            server.processRequests();
           
            return null;
        }
    }
 
    public static void main(String[] args) throws Exception 
    {
        String programName     = "JAASServer";
        Debug dbg              = new Debug();
 
        System.out.println(dbg.toString()); // XXXXXXX
 
        try {
            // Do not set useSubjectCredsOnly.
            // useSubjectCredsOnly defaults to "true" if not set.
 
            JAASServer server = new JAASServer(programName);
 
            server.processArgs(args);
    
            LoginContext loginCtxt = new LoginContext(programName,
                                           new Krb5CallbackHandler());
    
            dbg.out(Debug.OPTS_CAT_APPLICATION, programName + ": Login in ...");
 
            loginCtxt.login();
    
            dbg.out(Debug.OPTS_CAT_APPLICATION, programName + 
                                                ": Login successful");
    
            Subject subject = loginCtxt.getSubject();
    
            JAASServerAction serverAction = new JAASServerAction(server);
    
            Subject.doAsPrivileged(subject, serverAction, null);
        } catch (Exception exc) {
            dbg.out(Debug.OPTS_CAT_APPLICATION, programName +  " EXCEPTION");
            exc.printStackTrace();
            throw exc;
        }
    }
}

